@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 Pier Carlo Chiodi
+# Copyright (C) 2017-2021 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ class Ask(object):
         if self.next_answer:
             ans = self.next_answer
             self.next_answer = None
-            self.wr_out(ans)
+            self.wr_out(ans + "\n")
             return ans
         else:
             return input()
