@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 Pier Carlo Chiodi
+# Copyright (C) 2017-2021 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ from .errors import MissingDirError, MissingFileError, BuilderError, \
                     ARouteServerError, MissingArgumentError, \
                     TemplateRenderingError, CompatibilityIssuesError, \
                     ConfigError, MissingGeneralConfigFileError
-from .ipaddresses import IPNetwork
+from .ipaddresses import IPNetwork, IPAddress
 from .irrdb import IRRDBInfo
 from .cached_objects import CachedObject, normalize_expiry_time
 
@@ -141,7 +141,7 @@ class ConfigBuilder(object):
 
     def __init__(self, template_dir=None, template_name=None,
                  cache_dir=None, cache_expiry=CachedObject.DEFAULT_EXPIRY,
-                 bgpq3_path="bgpq3", bgpq3_host=IRRDBInfo.BGPQ3_DEFAULT_HOST,
+                 bgpq3_path="bgpq4", bgpq3_host=IRRDBInfo.BGPQ3_DEFAULT_HOST,
                  bgpq3_sources=IRRDBInfo.BGPQ3_DEFAULT_SOURCES,
                  rtt_getter_path=None, threads=4,
                  ip_ver=None, perform_graceful_shutdown=False,
@@ -730,11 +730,15 @@ class BIRDConfigBuilder(ConfigBuilder):
              "scrub_communities_in", "scrub_communities_out",
              "apply_blackhole_filtering_policy"]
 
+    IGNORABLE_ISSUES = ["max_prefix_count_rejected_routes"]
+
     AVAILABLE_VERSION = ["1.6.3", "1.6.4", "1.6.6", "1.6.7", "1.6.8",
-                         "2.0.7"]
+                         "2.0.7", "2.0.7+b962967e", "2.0.8"]
     DEFAULT_VERSION = "1.6.8"
 
     def validate_bgpspeaker_specific_configuration(self):
+        res = True
+
         if self.ip_ver is None and \
            version.parse(self.target_version) < version.parse("2.0"):
             raise BuilderError(
@@ -747,10 +751,88 @@ class BIRDConfigBuilder(ConfigBuilder):
         if hooks:
             if not isinstance(hooks, list):
                 raise BuilderError(
-                    "hooks must be a list of hook names"
+                    "hooks must be a list of hook names."
                 )
 
-        return True
+        for client in self.cfg_clients.cfg["clients"]:
+            if client["cfg"]["multihop"]:
+                if self.cfg_general["path_hiding"]:
+                    raise BuilderError(
+                        "multihop is not supported on BIRD configurations "
+                        "when path_hiding mitigation is enabled; "
+                        "see https://github.com/pierky/arouteserver/pull/61 "
+                        "for more details."
+                    )
+
+        if version.parse(self.target_version) == version.parse("2.0.7"):
+            max_prefix_count_rejected_routes_clients = []
+
+            for client in self.cfg_clients.cfg["clients"]:
+                max_prefix_count_rejected_routes = client["cfg"]["filtering"]["max_prefix"]["count_rejected_routes"]
+                if max_prefix_count_rejected_routes:
+                    max_prefix_count_rejected_routes_clients.append(client["ip"])
+
+            if (
+                self.cfg_general["filtering"]["max_prefix"]["count_rejected_routes"] or \
+                max_prefix_count_rejected_routes_clients
+            ):
+                if not self.process_bgpspeaker_specific_compatibility_issue(
+                    "max_prefix_count_rejected_routes",
+                    "In BIRD, the functionality represented by the "
+                    "'count_rejected_routes: True' option is "
+                    "implemented using the 'receive limit' statement. "
+                    "According to some tests, BIRD 2.0.7 is affected by "
+                    "an issue that prevents that statement from working "
+                    "correctly when it's used along with some other "
+                    "options that are needed by ARouteServer "
+                    "configurations (see {link_bird} for more details). "
+                    "Even though beginning with ARouteServer 1.0.1 the "
+                    "default value of 'count_rejected_routes' is True, "
+                    "it's not advisable to deploy any configuration for "
+                    "BIRD 2.0.7 that uses that setting at the moment. "
+                    "Now, there are 3 ways to unblock the build of the "
+                    "configuration: 1) this error can be ignored using "
+                    "the command line argument mentioned later on in "
+                    "this message; 2) the value of "
+                    "'count_rejected_routes' can be set to False; 3) "
+                    "--target-version can be set to 2.0.7+b962967e. "
+                    "If this error will be ignored, the configuration "
+                    "will be generated as if that option was set to "
+                    "False; this may be a good option if the goal is "
+                    "to have the desired behaviour of counting rejected "
+                    "routes towards the max-prefix limit implemented in "
+                    "any future release of BIRD 2.0 for which the issue "
+                    "will be solved. In this case, future releases of "
+                    "ARouteServer will skip this check if the "
+                    "--target-version will be set to the release for "
+                    "which the issue is fixed. "
+                    "The other option, that is to specifically configure "
+                    "'count_rejected_routes: False', may be the best one "
+                    "if the goal is to keep the currently available "
+                    "behaviour (that is to not count rejected routes "
+                    "towards the max-prefix limit) permanent in the "
+                    "configurations generated by this tool. For more "
+                    "details on how to configure it, see the general.yml "
+                    "file distributed with the package or check this "
+                    "URL: {link_ars}. The third option is to apply the "
+                    "patch mentioned at {patch_url} and pass the value "
+                    "2.0.7+b962967e via the --target-version command "
+                    "line argument.".format(
+                        link_bird=("https://www.mail-archive.com/bird-users"
+                                   "@network.cz/msg05597.html"),
+                        link_ars=("https://arouteserver.readthedocs.io/"
+                                  "en/latest/GENERAL.html#max-prefix-max-prefix"),
+                        patch_url=("https://www.mail-archive.com/bird-users"
+                                   "@network.cz/msg05638.html")
+                    )
+                ):
+                    res = False
+                else:
+                    self.cfg_general["filtering"]["max_prefix"]["count_rejected_routes"] = False
+                    for client in self.cfg_clients.cfg["clients"]:
+                        client["cfg"]["filtering"]["max_prefix"]["count_rejected_routes"] = False
+
+        return res
 
     def _include_local_file(self, local_file_id):
         return 'include "{}";\n\n'.format(
@@ -784,11 +866,13 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
                        "footer"]
     LOCAL_FILES_BASE_DIR = "/etc/bgpd"
 
-    AVAILABLE_VERSION = ["6.0", "6.1", "6.2", "6.3", "6.4", "6.5", "6.6", "6.7"]
-    DEFAULT_VERSION = "6.6"
+    AVAILABLE_VERSION = ["6.0", "6.1", "6.2", "6.3", "6.4", "6.5", "6.6", "6.7",
+                         "6.8"]
+    DEFAULT_VERSION = "6.7"
 
     IGNORABLE_ISSUES = ["path_hiding", "transit_free_action",
                         "add_path", "max_prefix_action",
+                        "max_prefix_count_rejected_routes",
                         "blackhole_filtering_rewrite_ipv6_nh",
                         "large_communities", "extended_communities",
                         "graceful_shutdown", "internal_communities",
@@ -836,6 +920,7 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
 
         add_path_clients = []
         max_prefix_action_clients = []
+        max_prefix_count_rejected_routes_clients = []
         for client in self.cfg_clients.cfg["clients"]:
             if client["cfg"]["add_path"]:
                 add_path_clients.append(client["ip"])
@@ -845,6 +930,10 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
                 if max_prefix_action not in ("shutdown", "restart"):
                     max_prefix_action_clients.append(client["ip"])
 
+            max_prefix_count_rejected_routes = client["cfg"]["filtering"]["max_prefix"]["count_rejected_routes"]
+            if not max_prefix_count_rejected_routes:
+                max_prefix_count_rejected_routes_clients.append(client["ip"])
+
         if add_path_clients:
             clients = add_path_clients
             cnt = len(clients)
@@ -872,6 +961,21 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
             ):
                 res = False
 
+        if max_prefix_count_rejected_routes_clients:
+            clients = max_prefix_count_rejected_routes_clients
+            cnt = len(clients)
+            if not self.process_bgpspeaker_specific_compatibility_issue(
+                "max_prefix_count_rejected_routes",
+                "Invalid max-prefix 'count_rejected_routes' option for "
+                "the following clients: {}{}; in OpenBGPD, the "
+                "only available behaviour is to have the "
+                "rejected routes counted towards the limit.".format(
+                    ", ".join(clients[:3]),
+                    "" if cnt <= 3 else " and {} more".format(cnt - 3)
+                )
+            ):
+                res = False
+
         if self.cfg_general["blackhole_filtering"]["policy_ipv6"] == "rewrite-next-hop" and \
             version.parse(self.target_version) < version.parse("6.1"):
             if not self.process_bgpspeaker_specific_compatibility_issue(
@@ -1119,3 +1223,75 @@ class TemplateContextDumper(ConfigBuilder):
         env.filters["to_yaml"] = to_yaml
         env.filters["parse_irrdb_info"] = parse_irrdb_info
         env.filters["parse_generic_irr_whois_records"] = parse_generic_irr_whois_records
+
+class IRRASSetBuilder(ConfigBuilder):
+
+    def enrich_j2_environment(self, env):
+
+        if self.ip_ver is None:
+            self.data["ip_ver_suffix"] = ""
+            self.data["ip_ver_descr"] = "IPv4 and IPv6"
+        else:
+            self.data["ip_ver_suffix"] = "-V{}".format(self.ip_ver)
+            self.data["ip_ver_descr"] = "IPv{}".format(self.ip_ver)
+
+        members = set()
+
+        for client in self.cfg_clients.cfg["clients"]:
+            if self.ip_ver is not None:
+                ip = client["ip"]
+                if IPAddress(ip).version != self.ip_ver:
+                    # The address family of this client is not the
+                    # current one used to build the configuration.
+                    continue
+
+            client_irrdb = client["cfg"]["filtering"]["irrdb"]
+
+            # Client's own ASN.
+            members.add("AS{}".format(client["asn"]))
+
+            # White lists.
+            if client_irrdb.get("white_list_asn", None):
+                for white_list_asn in client_irrdb.get("white_list_asn", []):
+                    members.add("AS{}".format(white_list_asn))
+
+            # The client has its own list of AS-SETs.
+            # Use it and move to the next client.
+            if client_irrdb["as_sets"]:
+                members.update(client_irrdb["as_sets"])
+                continue
+
+            # If we're here, it means that the client
+            # has no AS-SETs configured.
+            # Let's look into the 'asns' configuration.
+
+            asn = "AS{}".format(client["asn"])
+            if asn in self.cfg_asns.cfg["asns"] and \
+                self.cfg_asns.cfg["asns"][asn]["as_sets"]:
+
+                # The client ASN is configured in the 'asns'
+                # section of the clients.yml file and there
+                # are AS-SETs set on it. Let's use them.
+                members.update(self.cfg_asns.cfg["asns"][asn]["as_sets"])
+                continue
+
+            # Let's check if AS-SETs were found on PeeringDB.
+
+            as_sets_from_pdb = client.get("as_sets_from_pdb", None)
+            if as_sets_from_pdb:
+                logging.info("No AS-SETs provided for the '{}' client. "
+                             "Using AS{} + those obtained from PeeringDB: "
+                             "{}.".format(
+                                    client["id"], client["asn"],
+                                    ", ".join(as_sets_from_pdb)
+                                ))
+                members.update(as_sets_from_pdb)
+                continue
+
+            # No other AS-SETs found for the client.
+            logging.warning("No AS-SETs provided for the '{}' client. "
+                            "Only AS{} will be expanded.".format(
+                                client["id"], client["asn"]
+                            ))
+
+        self.data["as_sets_rpsl_objects"] = sorted(members)
