@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 Pier Carlo Chiodi
+# Copyright (C) 2017-2021 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,7 +14,8 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from .tpl_rendering import HTMLCommand, DumpTemplateContextCommand, \
-                          BIRDCommand, OpenBGPDCommand, BuildCommand
+                          BIRDCommand, OpenBGPDCommand, BuildCommand, \
+                          IRRASSetCommand
 from .check_new_release import CheckNewRelease
 from .clients_from_peeringdb import ClientsFromPeeringDBCommand
 from .clients_from_euroix import ClientsFromEuroIXCommand
@@ -32,6 +33,7 @@ all_commands = [
     OpenBGPDCommand,
     HTMLCommand,
     DumpTemplateContextCommand,
+    IRRASSetCommand,
     ClientsFromPeeringDBCommand,
     ClientsFromEuroIXCommand,
     SetupCommand,
