@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 Pier Carlo Chiodi
+# Copyright (C) 2017-2021 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ import yaml
 from .base import ARouteServerCommand
 
 from ..ask import Ask
-from ..builder import OpenBGPDConfigBuilder
+from ..builder import OpenBGPDConfigBuilder, BIRDConfigBuilder
 from ..config.program import program_config
 from ..errors import ARouteServerError
 from ..ipaddresses import IPNetwork
@@ -95,6 +95,9 @@ class ConfigureCommand(ARouteServerCommand):
                 raise ARouteServerError("Aborted!")
             if answer_ok:
                 break
+            else:
+                if self.preset_answers:
+                    raise ARouteServerError("Pre-set answer is invalid!")
         self.answers[answer_id] = answer
 
     def ask_list_of_ip_prefixes(self, text, raise_exc=False):
@@ -147,6 +150,12 @@ class ConfigureCommand(ARouteServerCommand):
                 options=OpenBGPDConfigBuilder.AVAILABLE_VERSION,
                 default=OpenBGPDConfigBuilder.AVAILABLE_VERSION[-1]
             )
+        else:
+            self.add_answer("version", self.ask.ask,
+                "Which version?",
+                options=BIRDConfigBuilder.AVAILABLE_VERSION,
+                default=BIRDConfigBuilder.DEFAULT_VERSION
+            )
 
         self.wr_text(
             None, title="Router server's ASN"
@@ -336,6 +345,22 @@ class ConfigureCommand(ARouteServerCommand):
             "PeeringDB is used to fetch networks prefix count."
         )
 
+        if self.answers["daemon"] == "bird":
+            filtering["reject_policy"] = {
+                "policy": "tag_and_reject"
+            }
+
+        if (
+            self.answers["daemon"] == "bird" and \
+            version.parse(self.answers["version"]) >= version.parse("2.0") and \
+            version.parse(self.answers["version"]) <= version.parse("2.0.7")
+        ):
+            # Why? See comments in v1.0.1 about the 'receive limit' bug in 2.0.7.
+            filtering["max_prefix"]["count_rejected_routes"] = False
+            self.notes.append(
+                "Rejected routes are not counted towards max-prefix limit."
+            )
+
         cfg["graceful_shutdown"] = {"enabled": False}
         if self.answers["daemon"] == "bird":
             cfg["graceful_shutdown"] = {"enabled": True}
@@ -353,6 +378,10 @@ class ConfigureCommand(ARouteServerCommand):
 
         cfg["communities"] = OrderedDict()
 
+        if self.answers["daemon"] == "bird":
+            add_comm("reject_cause",
+                     "65520:dyn_val", "rs_as:65520:dyn_val")
+
         add_comm("prefix_present_in_as_set",
                  "64512:11", "rs_as:64512:11")
         add_comm("prefix_not_present_in_as_set",
