@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 Pier Carlo Chiodi
+# Copyright (C) 2017-2021 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -58,6 +58,7 @@ class ConfigParserClients(ConfigParserBase):
                 "prepend_rs_as": ValidatorBool(mandatory=False),
                 "passive": ValidatorBool(mandatory=False),
                 "gtsm": ValidatorBool(mandatory=False),
+                "multihop": ValidatorUInt(mandatory=False),
                 "add_path": ValidatorBool(mandatory=False),
                 "filtering": {
                     "next_hop": {
@@ -100,6 +101,7 @@ class ConfigParserClients(ConfigParserBase):
                             mandatory=False
                         ),
                         "restart_after": ValidatorUInt(mandatory=False),
+                        "count_rejected_routes": ValidatorBool(mandatory=False),
                         "peering_db": {
                             "enabled": ValidatorBool(mandatory=False),
                             "increment": {
