@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 Pier Carlo Chiodi
+# Copyright (C) 2017-2021 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -105,6 +105,7 @@ class ConfigParserGeneral(ConfigParserBase):
         c["prepend_rs_as"] = ValidatorBool(default=False)
         c["path_hiding"] = ValidatorBool(default=True)
         c["passive"] = ValidatorBool(default=True)
+        c["multihop"] = ValidatorUInt(mandatory=False)
         c["gtsm"] = ValidatorBool(default=False)
         c["add_path"] = ValidatorBool(default=False)
 
@@ -194,6 +195,7 @@ class ConfigParserGeneral(ConfigParserBase):
             default="shutdown"
         )
         m["restart_after"] = ValidatorUInt(default=15, mandatory=True)
+        m["count_rejected_routes"] = ValidatorBool(default=True)
 
         f["reject_policy"] = OrderedDict()
         f["reject_policy"]["policy"] = ValidatorOption(
