@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 Pier Carlo Chiodi
+# Copyright (C) 2017-2021 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -396,6 +396,9 @@ class LiveScenario(ARouteServerTestCase):
             os.makedirs(dest_dir)
 
         for instance in cls.INSTANCES:
+            if not isinstance(instance, BGPSpeakerInstance):
+                continue
+
             path = os.path.join(dest_dir, "{}.txt".format(instance.name))
             routes = instance.get_routes(None, include_filtered=True)
             sorted_routes = sorted(routes,
@@ -732,14 +735,15 @@ class LiveScenario(ARouteServerTestCase):
             failure += self._instance_log_contains_errors_warning(inst)
             self.fail(failure)
 
-    def log_contains(self, inst, msg, instances={}):
+    def log_contains(self, inst, msg, instances={}, opposite=False):
         """Test if the BGP speaker's log contains the expected message.
 
         This only works for BGP speaker instances that support message
         logging: currently only BIRD.
 
         If no log entries are found, the ``TestCase.fail()`` method is
-        called and the test fails.
+        called and the test fails. If ``opposite`` is ``True``, the
+        failure is reported if a log entry is found.
 
         Args:
 
@@ -754,6 +758,9 @@ class LiveScenario(ARouteServerTestCase):
                 the *msg* argument. Macros are expanded using the BGP
                 speaker's specific client ID or protocol name.
 
+            opposite (bool): when set to True, the call fails if a match
+                is found.
+
         Example
         ---------
 
@@ -783,13 +790,20 @@ class LiveScenario(ARouteServerTestCase):
         if macros_dict:
             expanded_msg = expanded_msg.format(**macros_dict)
 
-        if not inst.log_contains(expanded_msg):
+        if not opposite and not inst.log_contains(expanded_msg):
             self.fail(
                 "Expected message not found on {} logs:\n\t{}".format(
                     inst.name, expanded_msg
                 ) + self._instance_log_contains_errors_warning(inst)
             )
 
+        if opposite and inst.log_contains(expanded_msg):
+            self.fail(
+                "Unexpected message found on {} logs:\n\t{}".format(
+                    inst.name, expanded_msg
+                ) + self._instance_log_contains_errors_warning(inst)
+            )
+
     def session_exists(self, inst_a, inst_b_or_ip):
         """Test if a BGP session between the two instances exists.
 
