@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 Pier Carlo Chiodi
+# Copyright (C) 2017-2021 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,9 +17,13 @@ import os
 import subprocess
 import time
 
-from .instances import InstanceError, BGPSpeakerInstance, InstanceNotRunning
+from .instances import (
+    BaseInstance,
+    InstanceError,
+    InstanceNotRunning
+)
 
-class DockerInstance(BGPSpeakerInstance):
+class DockerInstance(BaseInstance):
 
     DOCKER_PATH = "docker"
     DOCKER_INSTANCE_PREFIX = "ars_"
