@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020 Pier Carlo Chiodi
+# Copyright (C) 2017-2021 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -369,7 +369,7 @@ class OpenBGPDClassicInstance(OpenBGPDInstance, KVMInstance):
             return False, ""
         return False
 
-class OpenBGPDPortableInstance(OpenBGPDInstance, DockerInstance):
+class OpenBGPDPortableInstance(OpenBGPDInstance, DockerInstance, BGPSpeakerInstance):
     """This class implements OpenBGPD-specific methods for the Portable edition.
 
     This class is derived from :class:`DockerInstance`, that implements
@@ -480,8 +480,17 @@ class OpenBGPD67Instance(OpenBGPDClassicInstance):
     BGP_SPEAKER_VERSION = "6.7"
     TARGET_VERSION = "6.7"
 
-OpenBGPDPreviousInstance = OpenBGPD66Instance
-OpenBGPDLatestInstance = OpenBGPD67Instance
+class OpenBGPD68Instance(OpenBGPDClassicInstance):
+
+    VIRSH_DOMAINNAME = "arouteserver_openbgpd68"
+
+    TAG = "openbgpd68"
+
+    BGP_SPEAKER_VERSION = "6.8"
+    TARGET_VERSION = "6.8"
+
+OpenBGPDPreviousInstance = OpenBGPD67Instance
+OpenBGPDLatestInstance = OpenBGPD68Instance
 
 class OpenBGPD65PortableInstance(OpenBGPDPortableInstance):
 
@@ -499,7 +508,6 @@ class OpenBGPD66PortableInstance(OpenBGPDPortableInstance):
     # TARGET_VERSION not set here because it's assumed to be
     # the same of the OpenBGPD Latest one.
 
-
 class OpenBGPD67PortableInstance(OpenBGPDPortableInstance):
 
     DOCKER_IMAGE = "pierky/openbgpd:6.7p0"
@@ -510,4 +518,14 @@ class OpenBGPD67PortableInstance(OpenBGPDPortableInstance):
     # TARGET_VERSION not set here because it's assumed to be
     # the same of the OpenBGPD Latest one.
 
-OpenBGPDPortableLatestInstance = OpenBGPD67PortableInstance
+class OpenBGPD68PortableInstance(OpenBGPDPortableInstance):
+
+    DOCKER_IMAGE = "pierky/openbgpd:6.8p1"
+
+    TAG = "openbgpd68p"
+
+    BGP_SPEAKER_VERSION = "6.8p1"
+    # TARGET_VERSION not set here because it's assumed to be
+    # the same of the OpenBGPD Latest one.
+
+OpenBGPDPortableLatestInstance = OpenBGPD68PortableInstance
